CryptoUtils class

Constructors

CryptoUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decrypt256WithKey(String fullResponse, String secretKey) → String
encrypt256WithKey(String plainText, String secretKey) → String
generate16DigitNumber() → String